| <font style="color:black;">成功编码</font>    | <font style="color:black;">描述</font>    |
| --- | --- |
| 100    | 成功    |
| <font style="color:black;">错误编码</font>    | <font style="color:black;">描述</font>    |
| 101    | 缺少必要参数    |
| 102    | 校验问题    |
| 103    | 格式问题    |
| 104    | 用户问题    |
| 105 | 其他错误<br/>具体内容可见返回的**{Reason:}**字段<br/><font style="color:#595959;">示例： {   "ResultCode" : "105",   "Reason" : "查询该客户编码信息失败,请联系负责网点后重试!" }</font> |
| 106    | 该订单号已下单成功    |
| 401    | RequestData格式有误    |
| 402    | 缺少快递单号    |
| 403    | 快递单号有特殊字符    |
| 404    | 快递单号长度不符    |
| 405    | 超出查询次数限制(日查询次数<=3万)    |


